#line 2 "lib/route/cls/ematch_grammar.c"

#line 4 "lib/route/cls/ematch_grammar.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 0
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE ematch_restart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via ematch_restart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void ematch_restart (FILE *input_file ,yyscan_t yyscanner );
void ematch__switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE ematch__create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void ematch__delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void ematch__flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void ematch_push_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void ematch_pop_buffer_state (yyscan_t yyscanner );

static void ematch_ensure_buffer_stack (yyscan_t yyscanner );
static void ematch__load_buffer_state (yyscan_t yyscanner );
static void ematch__init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER ematch__flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE ematch__scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE ematch__scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE ematch__scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *ematch_alloc (yy_size_t ,yyscan_t yyscanner );
void *ematch_realloc (void *,yy_size_t ,yyscan_t yyscanner );
void ematch_free (void * ,yyscan_t yyscanner );

#define yy_new_buffer ematch__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        ematch_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ematch__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        ematch_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ematch__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

#define ematch_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 91
#define YY_END_OF_BUFFER 92
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[393] =
    {   0,
        0,    0,    0,    0,   92,   90,    1,   18,    2,   26,
       23,   24,   30,    5,    5,   12,    8,   10,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   91,    3,   91,    4,   90,    1,   14,    5,   90,
       28,   90,   29,   90,   90,   90,   40,   90,   90,   90,
       90,   90,   15,   90,   90,   90,   90,   32,   90,   90,
       90,   33,   90,   90,    7,    9,   90,   11,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   16,    3,    6,
       13,   19,   37,   90,   39,   90,   90,   90,   38,   17,

       90,   90,   42,   90,   90,   34,   35,   90,   47,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   31,   36,   25,   22,   90,   90,   21,   90,
       90,   90,   90,   90,   54,   90,   90,   48,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   86,   90,   27,   90,
       90,   90,   90,   90,   90,   90,   49,   90,   90,   57,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   53,   51,

       90,   43,   90,   87,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   20,   90,
       52,   88,   90,   50,   90,   90,   90,   90,   90,   90,
       90,   76,   90,   90,   80,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       66,   90,   90,   55,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   65,   90,   90,   90,   90,
       90,   60,   90,   90,   90,   90,   90,   90,   90,   59,
       90,   90,   41,   44,   45,   46,   56,   90,   74,   90,

       90,   58,   90,   90,   90,   90,   62,   90,   90,   61,
       90,   90,   90,   90,   90,   63,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   90,   89,
       72,   90,   90,   90,   70,   81,   82,   90,   90,   90,
       64,   71,   83,   90,   90,   90,   90,   90,   90,   90,
       90,   90,   90,   90,   90,   90,   90,   90,   77,   90,
       67,   75,   90,   68,   90,   90,   78,   90,   90,   84,
       69,   90,   90,   90,   90,   90,   90,   85,   73,   90,
       79,    0

    } ;

static yyconst YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    4,    5,    1,    1,    1,    6,    1,    7,
        8,    1,    9,    1,    1,    1,    1,   10,   11,   12,
       13,   14,   14,   15,   14,   16,   14,    1,    1,   17,
       18,   19,    1,    1,   20,   21,   22,   23,   24,   25,
        1,   26,   27,    1,   28,   29,   30,   31,   32,   33,
        1,   34,   35,   36,   37,    1,    1,   38,    1,    1,
        1,   39,    1,    1,   40,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,    1,   50,   51,   52,   53,
       54,   55,   56,   57,   58,   59,   60,   61,   62,   63,
       64,    1,    1,   65,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst YY_CHAR yy_meta[66] =
    {   0,
        1,    2,    3,    1,    3,    2,    2,    2,    2,    1,
        1,    1,    1,    1,    1,    1,    2,    2,    2,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    4,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    2
    } ;

static yyconst flex_uint16_t yy_base[396] =
    {   0,
        0,    0,   63,   64,  537,    0,   68,    0,  538,  530,
      538,  538,  538,   62,   69,  538,  538,  516,   55,   57,
       52,   55,   60,   67,   72,   73,   64,   79,   75,  100,
      115,   65,   83,  475,  102,  117,  118,   89,  121,  131,
      482,  467,    0,  538,  538,    0,  133,  538,  167,  179,
      538,  123,    0,  111,  124,  132,  516,  153,  138,  151,
      169,  171,    0,  172,  170,  178,  171,    0,  129,  515,
      517,    0,  469,  466,    0,    0,  485,    0,  183,  466,
       41,  471,  186,  475,  482,  183,  480,  538,    0,    0,
        0,    0,    0,  184,    0,  187,  189,  207,    0,    0,

      206,  218,    0,  208,  215,    0,    0,  479,  466,  474,
      466,  466,  194,  461,  455,  469,  461,  462,  469,  228,
      456,  455,    0,    0,    0,    0,  226,  213,    0,  217,
      456,  465,  464,  459,    0,  458,  438,    0,  447,  446,
      458,  452,  439,  204,  442,  438,  237,  453,  444,  451,
      434,  249,  236,  426,  199,  445,    0,  220,    0,  227,
      443,  435,  425,  432,  431,  428,    0,  430,  423,    0,
      432,  429,  427,  417,  419,  423,  417,  415,  419,  408,
      208,  409,  152,  424,  408,  414,  406,  421,  423,  408,
      417,  412,  415,  235,  261,  406,  413,  410,    0,    0,

      411,    0,  397,    0,  414,  399,  399,  411,  401,  387,
      400,  400,  406,  391,  385,  257,  400,  384,  389,  381,
      395,  379,  258,  378,  391,  383,  375,  370,    0,  262,
        0,    0,  392,    0,  382,  388,  386,  384,  371,  375,
      384,    0,  379,  382,    0,  368,  365,  360,  365,  369,
      364,  371,  375,  369,  361,  368,  355,  350,  360,  363,
        0,  367,  361,    0,  266,  294,  361,  363,  345,  362,
      350,  336,  342,  341,  354,    0,  345,  349,  332,  341,
      333,    0,  350,  350,  331,  334,  336,  340,  333,    0,
      266,  344,    0,    0,    0,    0,    0,  340,    0,  333,

      336,    0,  336,  320,  328,  332,    0,  335,  330,    0,
      323,  330,  325,  309,  325,    0,  324,  317,  307,  311,
      315,  318,  310,  322,  312,  320,  306,  299,  303,  305,
      314,  314,  300,  299,  297,  299,  304,  303,  296,    0,
        0,  305,  293,  302,    0,    0,    0,  289,  287,  287,
        0,    0,    0,  286,  279,  285,  283,  285,  287,  290,
      281,  265,  275,  277,  273,  270,  266,  261,    0,  268,
        0,    0,  264,    0,  265,  214,    0,  207,  209,    0,
        0,  205,  170,  109,   93,   75,   53,    0,    0,   57,
        0,  538,  325,  329,  333

    } ;

static yyconst flex_int16_t yy_def[396] =
    {   0,
      392,    1,  393,  393,  392,  394,  392,  394,  392,  392,
      392,  392,  392,  394,  394,  392,  392,  392,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  392,  395,  392,  392,  394,  392,  392,  394,  394,
      392,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  392,  395,   50,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,

      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,

      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,

      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,  394,  394,  394,  394,  394,  394,  394,  394,  394,
      394,    0,  392,  392,  392

    } ;

static yyconst flex_uint16_t yy_nxt[604] =
    {   0,
        6,    7,    7,    8,    9,   10,   11,   12,   13,   14,
       15,   15,   15,   15,   15,   15,   16,   17,   18,   19,
        6,   20,    6,   21,   22,    6,   23,    6,   24,   25,
       26,   27,   28,    6,   29,   30,   31,    6,    6,    6,
       19,    6,   20,   32,   33,   22,   34,    6,   23,    6,
       35,   36,   26,   27,   37,    6,   38,   39,   40,   31,
       41,    6,    6,    6,   42,   44,   44,   45,   45,   47,
       47,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   52,   54,   55,   56,  114,
       53,   59,   57,   58,  115,   60,   61,   63,   64,   50,

       65,   44,   44,  391,   62,   73,  390,   52,   54,   74,
       55,   56,   59,   53,   57,   58,   60,   61,   55,   64,
       63,   66,   65,   67,   50,   70,   62,   71,   58,   82,
       72,   68,  389,   69,   47,   47,   59,   64,   75,  388,
       60,   55,   66,   92,   67,   91,   65,   83,  105,   93,
       58,   84,   66,   68,   67,   77,   69,   79,   64,  387,
       78,   60,   68,   94,   69,   92,   91,   80,   65,  105,
       85,   93,   97,   86,   81,   67,   49,   49,   49,   49,
       49,   49,   49,   96,   68,   94,   98,   69,   90,   90,
       90,   90,   90,   90,   90,   97,  102,  217,   90,   90,

       90,   90,   90,   90,   99,   96,  100,  101,  104,   98,
      103,  218,  386,  123,  124,  103,  125,   97,  102,   90,
       90,   90,   90,   90,   90,  111,  126,   99,  117,  100,
      101,  121,  103,  104,  118,  123,  124,  103,  125,  112,
       97,  127,  128,  129,  136,  130,  172,  126,  159,  158,
      191,  160,  137,  194,  173,  192,  214,  385,  384,  195,
      383,  215,  382,  128,  127,  229,  129,  130,  144,  145,
      158,  159,  146,  147,  160,  148,  194,  176,  149,  150,
      186,  195,  151,  187,  152,  153,  154,  229,  188,  155,
      177,  182,  230,  183,  189,  265,  247,  257,  248,  258,

      184,  293,  185,  294,  295,  296,  318,  249,  381,  380,
      379,  378,  377,  376,  230,  250,  259,  375,  265,  374,
      373,  319,  372,  371,  293,   43,   43,   43,   43,   46,
      370,  369,   46,   89,   89,  368,  367,  366,  365,  364,
      363,  362,  361,  360,  359,  358,  357,  356,  355,  354,
      353,  352,  351,  350,  349,  348,  347,  346,  345,  344,
      343,  342,  341,  340,  339,  338,  337,  336,  335,  334,
      333,  332,  331,  330,  329,  328,  327,  326,  325,  324,
      323,  322,  321,  320,  317,  316,  315,  314,  313,  312,
      311,  310,  309,  308,  307,  306,  305,  304,  303,  302,

      301,  300,  299,  298,  297,  292,  291,  290,  289,  288,
      287,  286,  285,  284,  283,  282,  281,  280,  279,  278,
      277,  276,  275,  274,  273,  272,  271,  270,  269,  268,
      267,  266,  264,  263,  262,  261,  260,  256,  255,  254,
      253,  252,  251,  246,  245,  244,  243,  242,  241,  240,
      239,  238,  237,  236,  235,  234,  233,  232,  231,  228,
      227,  226,  225,  224,  223,  222,  221,  220,  219,  216,
      213,  212,  211,  210,  209,  208,  207,  206,  205,  204,
      203,  202,  201,  200,  199,  198,  197,  196,  193,  190,
      181,  180,  179,  178,  175,  174,  171,  170,  169,  168,

      167,  166,  165,  164,  163,  162,  161,  157,  156,  143,
      142,  141,  140,  139,  138,  135,  134,  133,  132,  131,
      122,  120,  119,  116,  113,  110,  109,  108,  107,  106,
       95,   88,   87,   76,   51,   48,  392,    5,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,

      392,  392,  392
    } ;

static yyconst flex_int16_t yy_chk[604] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    3,    4,    3,    4,    7,
        7,   14,   14,   14,   14,   14,   14,   14,   15,   15,
       15,   15,   15,   15,   15,   19,   20,   21,   22,   81,
       19,   25,   23,   24,   81,   25,   26,   27,   28,   14,

       29,    3,    4,  390,   26,   32,  387,   19,   20,   32,
       21,   22,   25,   19,   23,   24,   25,   26,   33,   28,
       27,   30,   29,   30,   14,   31,   26,   31,   35,   38,
       31,   30,  386,   30,   47,   47,   36,   37,   33,  385,
       36,   33,   30,   54,   30,   52,   39,   38,   69,   55,
       35,   38,   40,   30,   40,   35,   30,   36,   37,  384,
       35,   36,   40,   56,   40,   54,   52,   37,   39,   69,
       39,   55,   59,   40,   37,   40,   49,   49,   49,   49,
       49,   49,   49,   58,   40,   56,   60,   40,   50,   50,
       50,   50,   50,   50,   50,   59,   65,  183,   50,   50,

       50,   50,   50,   50,   61,   58,   62,   64,   67,   60,
       66,  183,  383,   94,   96,   86,   97,   79,   65,   50,
       50,   50,   50,   50,   50,   79,   98,   61,   83,   62,
       64,   86,   66,   67,   83,   94,   96,   86,   97,   79,
       79,  101,  102,  104,  113,  105,  144,   98,  128,  127,
      155,  130,  113,  158,  144,  155,  181,  382,  379,  160,
      378,  181,  376,  102,  101,  194,  104,  105,  120,  120,
      127,  128,  120,  120,  130,  120,  158,  147,  120,  120,
      153,  160,  120,  153,  120,  120,  120,  194,  153,  120,
      147,  152,  195,  152,  153,  230,  216,  223,  216,  223,

      152,  265,  152,  266,  266,  266,  291,  216,  375,  373,
      370,  368,  367,  366,  195,  216,  223,  365,  230,  364,
      363,  291,  362,  361,  265,  393,  393,  393,  393,  394,
      360,  359,  394,  395,  395,  358,  357,  356,  355,  354,
      350,  349,  348,  344,  343,  342,  339,  338,  337,  336,
      335,  334,  333,  332,  331,  330,  329,  328,  327,  326,
      325,  324,  323,  322,  321,  320,  319,  318,  317,  315,
      314,  313,  312,  311,  309,  308,  306,  305,  304,  303,
      301,  300,  298,  292,  289,  288,  287,  286,  285,  284,
      283,  281,  280,  279,  278,  277,  275,  274,  273,  272,

      271,  270,  269,  268,  267,  263,  262,  260,  259,  258,
      257,  256,  255,  254,  253,  252,  251,  250,  249,  248,
      247,  246,  244,  243,  241,  240,  239,  238,  237,  236,
      235,  233,  228,  227,  226,  225,  224,  222,  221,  220,
      219,  218,  217,  215,  214,  213,  212,  211,  210,  209,
      208,  207,  206,  205,  203,  201,  198,  197,  196,  193,
      192,  191,  190,  189,  188,  187,  186,  185,  184,  182,
      180,  179,  178,  177,  176,  175,  174,  173,  172,  171,
      169,  168,  166,  165,  164,  163,  162,  161,  156,  154,
      151,  150,  149,  148,  146,  145,  143,  142,  141,  140,

      139,  137,  136,  134,  133,  132,  131,  122,  121,  119,
      118,  117,  116,  115,  114,  112,  111,  110,  109,  108,
       87,   85,   84,   82,   80,   77,   74,   73,   71,   70,
       57,   42,   41,   34,   18,   10,    5,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,
      392,  392,  392,  392,  392,  392,  392,  392,  392,  392,

      392,  392,  392
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
/*
 * lib/route/cls/ematch_grammar.l	ematch expression grammar
 *
 *	This library is free software; you can redistribute it and/or
 *	modify it under the terms of the GNU Lesser General Public
 *	License as published by the Free Software Foundation version 2.1
 *	of the License.
 *
 * Copyright (c) 2010-2013 Thomas Graf <tgraf@suug.ch>
 */
#line 13 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
 #include <netlink-private/netlink.h>
 #include <netlink-private/tc.h>
 #include <netlink/netlink.h>
 #include <netlink/route/cls/ematch.h>
 #include <netlink/route/cls/ematch/cmp.h>
 #include <linux/tc_ematch/tc_em_cmp.h>
 #include "ematch_syntax.h"

 int ematch_get_column(yyscan_t);
 void ematch_set_column(int, yyscan_t);
#define YY_NO_INPUT 1

#line 733 "lib/route/cls/ematch_grammar.c"

#define INITIAL 0
#define QUOTE 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int ematch_lex_init (yyscan_t* scanner);

int ematch_lex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int ematch_lex_destroy (yyscan_t yyscanner );

int ematch_get_debug (yyscan_t yyscanner );

void ematch_set_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE ematch_get_extra (yyscan_t yyscanner );

void ematch_set_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *ematch_get_in (yyscan_t yyscanner );

void ematch_set_in  (FILE * _in_str ,yyscan_t yyscanner );

FILE *ematch_get_out (yyscan_t yyscanner );

void ematch_set_out  (FILE * _out_str ,yyscan_t yyscanner );

yy_size_t ematch_get_leng (yyscan_t yyscanner );

char *ematch_get_text (yyscan_t yyscanner );

int ematch_get_lineno (yyscan_t yyscanner );

void ematch_set_lineno (int _line_number ,yyscan_t yyscanner );

int ematch_get_column  (yyscan_t yyscanner );

void ematch_set_column (int _column_no ,yyscan_t yyscanner );

YYSTYPE * ematch_get_lval (yyscan_t yyscanner );

void ematch_set_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int ematch_wrap (yyscan_t yyscanner );
#else
extern int ematch_wrap (yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int ematch_lex \
               (YYSTYPE * yylval_param ,yyscan_t yyscanner);

#define YY_DECL int ematch_lex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			ematch_ensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				ematch__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		ematch__load_buffer_state(yyscanner );
		}

	{
#line 36 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"


#line 1010 "lib/route/cls/ematch_grammar.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 393 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 538 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 38 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"

	YY_BREAK
case 2:
YY_RULE_SETUP
#line 40 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{
				NL_DBG(4, "Beginning of quote\n");
				yylval->q.len = 32;
				if (!(yylval->q.data = calloc(1, yylval->q.len)))
					return ERROR;

				yylval->q.index = 0;
				BEGIN(QUOTE);
			}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 50 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{
				memcpy(yylval->q.data + yylval->q.index, yytext,
				       strlen(yytext));
				yylval->q.index += strlen(yytext);
			}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 56 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{
				BEGIN(0);
				return QUOTED;
			}
	YY_BREAK
case 5:
#line 63 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 6:
YY_RULE_SETUP
#line 63 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{
				yylval->i = strtoul(yytext, NULL, 0);
				return NUMBER;
			}
	YY_BREAK
case 7:
#line 69 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 8:
YY_RULE_SETUP
#line 69 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_EQ;
	YY_BREAK
case 9:
#line 71 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 10:
YY_RULE_SETUP
#line 71 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_GT;
	YY_BREAK
case 11:
#line 73 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 12:
YY_RULE_SETUP
#line 73 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_LT;
	YY_BREAK
case 13:
#line 76 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 14:
YY_RULE_SETUP
#line 76 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_REL_AND; return LOGIC; }
	YY_BREAK
case 15:
#line 78 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 16:
YY_RULE_SETUP
#line 78 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_REL_OR; return LOGIC; }
	YY_BREAK
case 17:
#line 80 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 18:
YY_RULE_SETUP
#line 80 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return NOT;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 82 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_CMP; return EMATCH_CMP; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 83 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_NBYTE; return EMATCH_NBYTE; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 84 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_TEXT; return EMATCH_TEXT; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 85 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_META; return EMATCH_META; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 87 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_OPEN;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 88 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_CLOSE;
	YY_BREAK
case 25:
#line 90 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 26:
YY_RULE_SETUP
#line 90 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_MASK;
	YY_BREAK
case 27:
#line 92 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 28:
YY_RULE_SETUP
#line 92 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_SHIFT;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 93 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_AT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 94 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_PLUS;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 95 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_FROM;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 96 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return KW_TO;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 98 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_ALIGN_U8; return ALIGN; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 99 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_ALIGN_U16; return ALIGN; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 100 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_EM_ALIGN_U32; return ALIGN; }
	YY_BREAK
case 36:
#line 103 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 37:
YY_RULE_SETUP
#line 103 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_LAYER_LINK; return LAYER; }
	YY_BREAK
case 38:
#line 105 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 39:
#line 106 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 40:
YY_RULE_SETUP
#line 106 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_LAYER_NETWORK; return LAYER; }
	YY_BREAK
case 41:
#line 108 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
case 42:
YY_RULE_SETUP
#line 108 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{ yylval->i = TCF_LAYER_TRANSPORT; return LAYER; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 110 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_RANDOM;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 111 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_LOADAVG_0;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 112 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_LOADAVG_1;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 113 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_LOADAVG_2;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 114 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_DEV;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 115 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_PRIO;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 116 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_PROTO;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 117 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_PKTTYPE;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 118 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_PKTLEN;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 119 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_DATALEN;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 120 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_MACLEN;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 121 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_MARK;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 122 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_TCINDEX;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 123 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_RTCLASSID;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 124 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_RTIIF;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 125 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_FAMILY;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 126 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_STATE;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 127 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_REUSE;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 128 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_REFCNT;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 129 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_RCVBUF;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 130 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_SNDBUF;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 131 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_SHUTDOWN;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 132 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_PROTO;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 133 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_TYPE;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 134 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_RMEM_ALLOC;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 135 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_WMEM_ALLOC;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 136 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_WMEM_QUEUED;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 137 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_RCV_QLEN;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 138 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_SND_QLEN;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 139 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_ERR_QLEN;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 140 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_FORWARD_ALLOCS;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 141 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_ALLOCS;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 142 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_ROUTE_CAPS;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 143 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_HASH;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 144 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_LINGERTIME;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 145 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_ACK_BACKLOG;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 146 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_MAX_ACK_BACKLOG;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 147 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_PRIO;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 148 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_RCVLOWAT;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 149 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_RCVTIMEO;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 150 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_SNDTIMEO;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 151 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_SENDMSG_OFF;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 152 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_WRITE_PENDING;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 153 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_VLAN;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 154 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_RXHASH;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 156 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_DEVNAME;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 157 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
return META_SK_BOUND_IF;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 160 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
{
				yylval->s = strdup(yytext);
				if (yylval->s == NULL)
					return ERROR;
				NL_DBG(4, "lex STR=%s\n", yylval->s);
				return STR;
			}
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 167 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
ECHO;
	YY_BREAK
#line 1508 "lib/route/cls/ematch_grammar.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(QUOTE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * ematch_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( ematch_wrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of ematch_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	yy_size_t number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					ematch_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			ematch_restart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) ematch_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 393 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 393 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 392);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					ematch_restart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( ematch_wrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void ematch_restart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        ematch_ensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            ematch__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	ematch__init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	ematch__load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void ematch__switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		ematch_pop_buffer_state();
	 *		ematch_push_buffer_state(new_buffer);
     */
	ematch_ensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	ematch__load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (ematch_wrap()) processing, but the only time this flag
	 * is looked at is after ematch_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void ematch__load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE ematch__create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) ematch_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ematch__create_buffer()" );

	b->yy_buf_size = (yy_size_t)size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) ematch_alloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in ematch__create_buffer()" );

	b->yy_is_our_buffer = 1;

	ematch__init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with ematch__create_buffer()
 * @param yyscanner The scanner object.
 */
    void ematch__delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		ematch_free((void *) b->yy_ch_buf ,yyscanner );

	ematch_free((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a ematch_restart() or at EOF.
 */
    static void ematch__init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	ematch__flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then ematch__init_buffer was _probably_
     * called from ematch_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void ematch__flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		ematch__load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void ematch_push_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	ematch_ensure_buffer_stack(yyscanner);

	/* This block is copied from ematch__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from ematch__switch_to_buffer. */
	ematch__load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void ematch_pop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	ematch__delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		ematch__load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void ematch_ensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)ematch_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in ematch_ensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)ematch_realloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in ematch_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE ematch__scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) ematch_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ematch__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	ematch__switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to ematch_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       ematch__scan_bytes() instead.
 */
YY_BUFFER_STATE ematch__scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return ematch__scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to ematch_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE ematch__scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) ematch_alloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in ematch__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = ematch__scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in ematch__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE ematch_get_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int ematch_get_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int ematch_get_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *ematch_get_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *ematch_get_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t ematch_get_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *ematch_get_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void ematch_set_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void ematch_set_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "ematch_set_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void ematch_set_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "ematch_set_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see ematch__switch_to_buffer
 */
void ematch_set_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void ematch_set_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int ematch_get_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void ematch_set_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * ematch_get_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void ematch_set_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* ematch_lex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int ematch_lex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) ematch_alloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* ematch_lex_init_extra has the same functionality as ematch_lex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to ematch_alloc in
 * the yyextra field.
 */

int ematch_lex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    ematch_set_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) ematch_alloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    ematch_set_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from ematch_lex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * ematch_lex_init()
     */
    return 0;
}

/* ematch_lex_destroy is for both reentrant and non-reentrant scanners. */
int ematch_lex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		ematch__delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		ematch_pop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	ematch_free(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        ematch_free(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * ematch_lex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    ematch_free ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *ematch_alloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return (void *) malloc( size );
}

void *ematch_realloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void ematch_free (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see ematch_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 167 "../libnl-3.5.0/lib/route/cls/ematch_grammar.l"
